# footprints

[![example workflow](https://github.com/UMR-CNRM/footprints/actions/workflows/lint_test_and_doc.yml/badge.svg)](https://github.com/UMR-CNRM/footprints/actions/workflows/lint_test_and_doc.yml)
[![Documentation Status](https://readthedocs.org/projects/footprints/badge/?version=latest)](https://footprints.readthedocs.io/)
[![PyPI version](https://badge.fury.io/py/footprints.svg)](https://badge.fury.io/py/footprints)

*footprints* is a generic multi-purpose fabric for objects with tunable
footprints, i.e. some set of key/value pairs that attributes (possibly
optional) could cover.

Originally, it has been developed as part of the *Vortex* project. Recently
the  code has been extracted from the *Vortex* code base. It is now presented
as an independent Python package.

## Contributing

Please review [CONTRIBUTING.md](CONTRIBUTING.md) for details on our
development process.
